@@ -7,7 +7,17 @@ import pooch
 import deciphon_api.resources
 from deciphon_api import __name__, __version__
 
-__all__ = ["FileName", "filepath", "prods_file_content", "env_example_content"]
+__all__ = [
+    "FileName",
+    "filepath",
+    "prods_file_content",
+    "env_example_content",
+    "prods_as_gff_content",
+    "prods_as_path_content",
+    "prods_as_fragment_content",
+    "prods_as_codon_content",
+    "prods_as_amino_content",
+]
 
 GOODBOY = pooch.create(
     path=pooch.os_cache(__name__),
@@ -40,5 +50,27 @@ def prods_file_content() -> str:
     return importlib.resources.read_text(deciphon_api.resources, "prods_file.tsv")
 
 
+def prods_as_gff_content() -> str:
+    return importlib.resources.read_text(deciphon_api.resources, "prods_as_gff.gff")
+
+
+def prods_as_path_content() -> str:
+    return importlib.resources.read_text(deciphon_api.resources, "prods_as_path.fasta")
+
+
+def prods_as_fragment_content() -> str:
+    return importlib.resources.read_text(
+        deciphon_api.resources, "prods_as_fragment.fasta"
+    )
+
+
+def prods_as_codon_content() -> str:
+    return importlib.resources.read_text(deciphon_api.resources, "prods_as_codon.fasta")
+
+
+def prods_as_amino_content() -> str:
+    return importlib.resources.read_text(deciphon_api.resources, "prods_as_amino.fasta")
+
+
 def env_example_content() -> str:
     return importlib.resources.read_text(deciphon_api.resources, ".env.example")
